@@ -1,6 +1,7 @@
 /*
     libparted - a library for manipulating disk partitions
-    Copyright (C) 1999-2001, 2004-2005, 2007-2009 Free Software Foundation, Inc.
+    Copyright (C) 1999-2001, 2004-2005, 2007-2010 Free Software
+    Foundation, Inc.
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -85,6 +86,7 @@ static const char MBR_BOOT_CODE[] = {
 #define PARTITION_LINUX		0x83
 #define PARTITION_LINUX_EXT	0x85
 #define PARTITION_LINUX_LVM	0x8e
+#define PARTITION_HFS		0xaf
 #define PARTITION_SUN_UFS	0xbf
 #define PARTITION_DELL_DIAG	0xde
 #define PARTITION_GPT		0xee
@@ -142,6 +144,10 @@ typedef struct {
 					 * logical partitions */
 } OrigState;
 
+typedef struct {
+        int             cylinder_alignment;
+} DosDiskData;
+
 typedef struct {
 	unsigned char	system;
 	int		boot;
@@ -227,8 +233,16 @@ msdos_alloc (const PedDevice* dev)
 	PED_ASSERT (dev != NULL, return NULL);
 
 	disk = _ped_disk_alloc ((PedDevice*)dev, &msdos_disk_type);
-	if (disk)
-		disk->disk_specific = NULL;
+        if (disk) {
+		DosDiskData *disk_specific = ped_malloc(sizeof *disk_specific);
+                if (!disk_specific) {
+                        free (disk);
+                        return NULL;
+                }
+                disk_specific->cylinder_alignment = 1;
+                disk->disk_specific = disk_specific;
+        }
+
 	return disk;
 }
 
@@ -240,7 +254,10 @@ msdos_duplicate (const PedDisk* disk)
 	new_disk = ped_disk_new_fresh (disk->dev, &msdos_disk_type);
 	if (!new_disk)
 		return NULL;
-	new_disk->disk_specific = NULL;
+
+        memcpy(new_disk->disk_specific, disk->disk_specific,
+               sizeof(DosDiskData));
+
 	return new_disk;
 }
 
@@ -249,27 +266,46 @@ msdos_free (PedDisk* disk)
 {
 	PED_ASSERT (disk != NULL, return);
 
+	DosDiskData *disk_specific = disk->disk_specific;
 	_ped_disk_free (disk);
+	free(disk_specific);
 }
 
-#ifndef DISCOVER_ONLY
 static int
-msdos_clobber (PedDevice* dev)
+msdos_disk_set_flag (PedDisk *disk, PedDiskFlag flag, int state)
 {
-	PED_ASSERT (dev != NULL, return 0);
-	PED_ASSERT (msdos_probe (dev), return 0);
+        DosDiskData *disk_specific = disk->disk_specific;
+        switch (flag) {
+        case PED_DISK_CYLINDER_ALIGNMENT:
+                disk_specific->cylinder_alignment = !!state;
+                return 1;
+        default:
+                return 0;
+        }
+}
 
-	void *label;
-	if (!ptt_read_sector (dev, 0, &label))
-		return 0;
+static int
+msdos_disk_get_flag (const PedDisk *disk, PedDiskFlag flag)
+{
+        DosDiskData *disk_specific = disk->disk_specific;
+        switch (flag) {
+        case PED_DISK_CYLINDER_ALIGNMENT:
+                return disk_specific->cylinder_alignment;
+        default:
+                return 0;
+        }
+}
 
-	DosRawTable *table = label;
-	table->magic = 0;
-        int write_ok = ped_device_write (dev, (void*) table, 0, 1);
-        free (label);
-	return write_ok;
+static int
+msdos_disk_is_flag_available (const PedDisk *disk, PedDiskFlag flag)
+{
+        switch (flag) {
+        case PED_DISK_CYLINDER_ALIGNMENT:
+               return 1;
+        default:
+               return 0;
+        }
 }
-#endif /* !DISCOVER_ONLY */
 
 static int
 chs_get_cylinder (const RawCHS* chs)
@@ -819,7 +855,6 @@ read_table (PedDisk* disk, PedSector sector, int is_extended_table)
 	PedPartition*		part;
 	PedPartitionType	type;
 	PedSector		lba_offset;
-	PedConstraint*		constraint_exact;
 
 	PED_ASSERT (disk != NULL, return 0);
 	PED_ASSERT (disk->dev != NULL, return 0);
@@ -890,10 +925,12 @@ read_table (PedDisk* disk, PedSector sector, int is_extended_table)
 		if (type != PED_PARTITION_EXTENDED)
 			part->fs_type = ped_file_system_probe (&part->geom);
 
-		constraint_exact = ped_constraint_exact (&part->geom);
-		if (!ped_disk_add_partition (disk, part, constraint_exact))
-			goto error;
+		PedConstraint *constraint_exact
+		  = ped_constraint_exact (&part->geom);
+		bool ok = ped_disk_add_partition (disk, part, constraint_exact);
 		ped_constraint_destroy (constraint_exact);
+		if (!ok)
+			goto error;
 
 		/* non-nested extended partition */
 		if (part->type == PED_PARTITION_EXTENDED) {
@@ -1204,7 +1241,6 @@ msdos_partition_new (const PedDisk* disk, PedPartitionType part_type,
 	}
 	return part;
 
-	free (dos_data);
 error_free_part:
 	free (part);
 error:
@@ -1319,7 +1355,10 @@ msdos_partition_set_system (PedPartition* part,
 		   || !strcmp (fs_type->name, "hpfs")) {
 		dos_data->system = PARTITION_NTFS;
 		dos_data->system |= dos_data->hidden ? PART_FLAG_HIDDEN : 0;
-	} else if (!strcmp (fs_type->name, "sun-ufs"))
+	} else if (!strcmp (fs_type->name, "hfs")
+		   || !strcmp (fs_type->name, "hfs+"))
+		dos_data->system = PARTITION_HFS;
+	else if (!strcmp (fs_type->name, "sun-ufs"))
 		dos_data->system = PARTITION_SUN_UFS;
 	else if (is_linux_swap (fs_type->name))
 		dos_data->system = PARTITION_LINUX_SWAP;
@@ -1974,10 +2013,11 @@ msdos_partition_align (PedPartition* part, const PedConstraint* constraint)
 	PedCHSGeometry	bios_geom;
 	DosPartitionData* dos_data;
 
- 	PED_ASSERT (part != NULL, return 0);
+	PED_ASSERT (part != NULL, return 0);
 	PED_ASSERT (part->disk_specific != NULL, return 0);
 
 	dos_data = part->disk_specific;
+
 	if (dos_data->system == PARTITION_LDM && dos_data->orig) {
 		PedGeometry *orig_geom = &dos_data->orig->geom;
 
@@ -1997,7 +2037,9 @@ msdos_partition_align (PedPartition* part, const PedConstraint* constraint)
 
 	partition_probe_bios_geometry (part, &bios_geom);
 
-	if (_align (part, &bios_geom, constraint))
+	DosDiskData *disk_specific = part->disk->disk_specific;
+	if (disk_specific->cylinder_alignment
+	    && _align(part, &bios_geom, constraint))
 		return 1;
 	if (_align_no_geom (part, constraint))
 		return 1;
@@ -2154,7 +2196,10 @@ add_startend_metadata (PedDisk* disk)
 	else
 		init_end = PED_MIN (dev->bios_geom.sectors - 1, init_end - 1);
 
-	if (!get_end_last_nonfree_part(disk, &final_start))
+        DosDiskData *disk_specific = disk->disk_specific;
+        if (!disk_specific->cylinder_alignment)
+                final_start = dev->length - 1;
+        else if (!get_end_last_nonfree_part(disk, &final_start))
 		final_start = ped_round_down_to (dev->length, cyl_size);
 	else
 		final_start = PED_MAX (final_start + 1,
@@ -2274,56 +2319,21 @@ msdos_get_max_supported_partition_count(const PedDisk* disk, int *max_n)
 	return true;
 }
 
-/*
- * Enforce some restrictions inherent in the DOS partition table format.
- * 1. Partition size must be smaller than 2^32 (unsigned int) sectors.
- *    If sector size is 512 bytes, this results in 2T aprox.
- * 2. Partition starting sector number must be smaller than 2^32.
- */
-static bool
-msdos_partition_check (const PedPartition* part)
-{
-	if (!ptt_partition_max_start_len("msdos", part))
-		return false;
-
-	return true;
-}
+#include "pt-common.h"
+PT_define_limit_functions (msdos)
 
 static PedDiskOps msdos_disk_ops = {
-	probe:			msdos_probe,
-#ifndef DISCOVER_ONLY
-	clobber:		msdos_clobber,
-#else
 	clobber:		NULL,
-#endif
-	alloc:			msdos_alloc,
-	duplicate:		msdos_duplicate,
-	free:			msdos_free,
-	read:			msdos_read,
-#ifndef DISCOVER_ONLY
-	write:			msdos_write,
-#else
-	write:			NULL,
-#endif
+	write:			NULL_IF_DISCOVER_ONLY (msdos_write),
+
+	disk_set_flag:          msdos_disk_set_flag,
+	disk_get_flag:          msdos_disk_get_flag,
+	disk_is_flag_available: msdos_disk_is_flag_available,
 
-	partition_new:		msdos_partition_new,
-	partition_duplicate:	msdos_partition_duplicate,
-	partition_destroy:	msdos_partition_destroy,
-	partition_set_system:	msdos_partition_set_system,
-	partition_set_flag:	msdos_partition_set_flag,
-	partition_get_flag:	msdos_partition_get_flag,
-	partition_is_flag_available:	msdos_partition_is_flag_available,
 	partition_set_name:	NULL,
 	partition_get_name:	NULL,
-	partition_align:	msdos_partition_align,
-	partition_enumerate:	msdos_partition_enumerate,
-	partition_check:	msdos_partition_check,
 
-	alloc_metadata:		msdos_alloc_metadata,
-	get_max_primary_partition_count:
-				msdos_get_max_primary_partition_count,
-	get_max_supported_partition_count:
-				msdos_get_max_supported_partition_count
+  PT_op_function_initializers (msdos)
 };
 
 static PedDiskType msdos_disk_type = {
