@@ -1,7 +1,7 @@
 #!/bin/sh
 # verify that partition maxima-querying functions work
 
-# Copyright (C) 2009 Free Software Foundation, Inc.
+# Copyright (C) 2009-2010 Free Software Foundation, Inc.
 
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -23,8 +23,10 @@ fi
 
 : ${srcdir=.}
 . $srcdir/t-lib.sh
+ss=$sector_size_
 
 fail=0
+ss=$sector_size_
 dev=dev-file
 PATH="..:$PATH"
 export PATH
@@ -33,7 +35,7 @@ export PATH
 for t in msdos gpt dvh sun mac bsd amiga loop pc98; do
     echo $t
     rm -f $dev
-    dd if=/dev/zero of=$dev bs=512 count=1 seek=10000 || { fail=1; continue; }
+    dd if=/dev/zero of=$dev bs=$ss count=1 seek=10000 || { fail=1; continue; }
     parted -s $dev mklabel $t || { fail=1; continue; }
 
     #case $t in pc98) sleep 999d;; esac
